@@ -321,7 +321,31 @@ openSkiesStateVectorSet <- R6Class(
         }
       }
       return(flights)
-    }, 
+    },
+    remove_redundants = function(updateType = "position") {
+      if(!self$time_series){
+        warning(strwrap("Method remove_redundants is intended to be used to remove
+                         state vectors of a time series without information update with
+                         respect to older state vectors, and therefore should only be applied
+                         to sets of state vectors that represent time series.", 
+                        initial="", prefix="\n"))
+      }
+      if(!(updateType %in% c("position", "any"))){
+        stop(strwrap(paste(samplesAggregationMethod, 
+                           " is not a valid update type to remove redundant state vectors.
+                           Please choose from either 'position' or 'any'", sep=""), 
+                     initial="", prefix="\n"))
+      }
+      if(updateType == "position") {
+        updateField <- "last_position_update_time"
+      } else if (updateType == "any") {
+        updateField <- "last_any_update_time"
+      } 
+      self$sort_by_field(updateField)
+      nonRedundantIndeces <- !duplicated(self$get_values(updateField))
+      self$state_vectors <- self$state_vectors[nonRedundantIndeces]
+      invisible(self)
+    },
     print = function(...) {
       cat("State vector set with ", length(self$state_vectors), " state vectors\n", sep = "")
       cat("Requested time: ", as.character(self$requested_time), " ", 
@@ -488,20 +512,18 @@ openSkiesFlight <- R6Class(
       duration <- arrivalTime - departureTime
       return(duration)
     },
-    distance_to_flight = function(flight, numberSamples=15, samplesAggregationMethod="concatenated", method="euclidean", useAngles=FALSE){
+    distance_to_flight = function(flight, numberSamples=15, samplesAggregationMethod="concatenated", method="euclidean", additionalFields=NULL){
       if(!(samplesAggregationMethod %in% c("concatenated", "average"))){
         stop(paste(samplesAggregationMethod, " is not a valid aggregation method.", sep=""))
       }
-      features1 = getVectorSetFeatures(self$state_vectors, resamplingSize=numberSamples, useAngles=useAngles)
-      features2 = getVectorSetFeatures(flight$state_vectors, resamplingSize=numberSamples, useAngles=useAngles)
+      features1 = getVectorSetFeatures(self$state_vectors, resamplingSize=numberSamples, 
+                                       fields=c("longitude", "latitude", additionalFields))
+      features2 = getVectorSetFeatures(flight$state_vectors, resamplingSize=numberSamples,
+                                       fields=c("longitude", "latitude", additionalFields))
       if(samplesAggregationMethod == "concatenated"){
         distance = dist(rbind(features1, features2), method)
       } else if(samplesAggregationMethod == "average"){
-        if(useAngles){
-          numFeatures = 3
-        } else {
-          numFeatures = 2
-        }
+        numFeatures <- 2 + length(additionalFields)
         numPoints = length(features1)/numFeatures
         distancesSum = 0
         for (i in 1:numPoints) {
